Enum ruma_api::AuthScheme [−][src]
pub enum AuthScheme {
None,
AccessToken,
ServerSignatures,
QueryOnlyAccessToken,
}Expand description
Authentication scheme used by the endpoint.
Variants
No authentication is performed.
Authentication is performed by including an access token in the Authentication http
header, or an access_token query parameter.
It is recommended to use the header over the query parameter.
Authentication is performed by including X-Matrix signatures in the request headers, as defined in the federation API.
Authentication is performed by setting the access_token query parameter.