Enum ruma_api::SendAccessToken [−][src]
An enum to control whether an access token should be added to outgoing requests
Variants
IfRequired(&'a str)Add the given access token to the request only if the METADATA on the request requires it
Tuple Fields of IfRequired
0: &'a strAlways(&'a str)Always add the access token
Tuple Fields of Always
0: &'a strDon’t add an access token. This will lead to an error if the request endpoint requires authentication
Implementations
Get the access token for an endpoint that requires one.
Returns Some(_) if self contains an access token.
Get the access token for an endpoint that should not require one.
Returns Some(_) only if self is SendAccessToken::Always(_).