[][src]Trait ruma_api::Endpoint

pub trait Endpoint: Outgoing + TryInto<Request<Vec<u8>>, Error = Error> where
    Self::Incoming: TryFrom<Request<Vec<u8>>, Error = Error>,
    <Self::Response as Outgoing>::Incoming: TryFrom<Response<Vec<u8>>, Error = Error>, 
{ type Response: Outgoing + TryInto<Response<Vec<u8>>, Error = Error>; const METADATA: Metadata; }

A Matrix API endpoint.

The type implementing this trait contains any data needed to make a request to the endpoint.

Associated Types

type Response: Outgoing + TryInto<Response<Vec<u8>>, Error = Error>

Data returned in a successful response from the endpoint.

Loading content...

Associated Constants

const METADATA: Metadata

Metadata about the endpoint.

Loading content...

Implementors

Loading content...