[−][src]Enum ruma_api::error::IntoHttpError
An error when converting one of ruma's endpoint-specific request or response types to the corresponding http type.
Variants (Non-exhaustive)
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Tried to create an authentication request without an access token.
Json(Error)JSON serialization failed.
Query(Error)Query parameter serialization failed.
Header(InvalidHeaderValue)Header serialization failed.
Http(Error)HTTP request construction failed.