[−][src]Struct ruma_api::Metadata
Metadata about an API endpoint.
Fields
description: &'static strA human-readable description of the endpoint.
method: MethodThe HTTP method used by this endpoint.
name: &'static strA unique identifier for this endpoint.
path: &'static strThe path of this endpoint's URL, with variable names where path parameters should be filled in during a request.
rate_limited: boolWhether or not this endpoint is rate limited by the server.
authentication: AuthSchemeWhat authentication scheme the server uses for this endpoint.