[][src]Struct ruma_api::Metadata

pub struct Metadata {
    pub description: &'static str,
    pub method: Method,
    pub name: &'static str,
    pub path: &'static str,
    pub rate_limited: bool,
    pub requires_authentication: bool,
}

Metadata about an API endpoint.

Fields

description: &'static str

A human-readable description of the endpoint.

method: Method

The HTTP method used by this endpoint.

name: &'static str

A unique identifier for this endpoint.

path: &'static str

The path of this endpoint's URL, with variable names where path parameters should be filled in during a request.

rate_limited: bool

Whether or not this endpoint is rate limited by the server.

requires_authentication: bool

Whether or not the server requires an authenticated user for this endpoint.