pub struct Metadata {
pub description: &'static str,
pub method: Method,
pub name: &'static str,
pub path: &'static str,
pub rate_limited: bool,
pub requires_authentication: bool,
}Expand description
Metadata about an API endpoint.
Fields
description: &'static strA human-readable description of the endpoint.
method: MethodThe HTTP method used by this endpoint.
name: &'static strA unique identifier for this endpoint.
path: &'static strThe path of this endpoint’s URL, with variable names where path parameters should be filled in during a request.
rate_limited: boolWhether or not this endpoint is rate limited by the server.
requires_authentication: boolWhether or not the server requires an authenticated user for this endpoint.