Trait ruma_api::OutgoingResponse [−][src]
pub trait OutgoingResponse {
fn try_into_http_response(self) -> Result<Response<Vec<u8>>, IntoHttpError>;
}A request type for a Matrix API endpoint, used for sending responses.
Required methods
fn try_into_http_response(self) -> Result<Response<Vec<u8>>, IntoHttpError>[src]
Tries to convert this response into an http::Response.
This method should only fail when when invalid header values are specified. It may also fail with a serialization error in case of bugs in Ruma though.